==> zio-aws-codeartifact_3-5.17.146.2-sources.jar: zio/aws/codeartifact/model/AssociateExternalConnectionRequest.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codeartifact.model.primitives.{
  ExternalConnectionName,
  RepositoryName,
  AccountId,
  DomainName
}
import scala.jdk.CollectionConverters.*
final case class AssociateExternalConnectionRequest(
    domain: DomainName,
    domainOwner: Option[AccountId] = None,
    repository: RepositoryName,
    externalConnection: ExternalConnectionName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest = {
    import AssociateExternalConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
      .builder()
      .domain(DomainName.unwrap(domain): java.lang.String)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .repository(RepositoryName.unwrap(repository): java.lang.String)
      .externalConnection(
        ExternalConnectionName.unwrap(externalConnection): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.AssociateExternalConnectionRequest.ReadOnly =
    zio.aws.codeartifact.model.AssociateExternalConnectionRequest
      .wrap(buildAwsValue())
}
object AssociateExternalConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.AssociateExternalConnectionRequest =
      zio.aws.codeartifact.model.AssociateExternalConnectionRequest(
        domain,
        domainOwner.map(value => value),
        repository,
        externalConnection
      )
    def domain: DomainName
    def domainOwner: Option[AccountId]
    def repository: RepositoryName
    def externalConnection: ExternalConnectionName
    def getDomain: ZIO[Any, Nothing, DomainName] = ZIO.succeed(domain)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getRepository: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repository)
    def getExternalConnection: ZIO[Any, Nothing, ExternalConnectionName] =
      ZIO.succeed(externalConnection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
  ) extends zio.aws.codeartifact.model.AssociateExternalConnectionRequest.ReadOnly {
    override val domain: DomainName =
      zio.aws.codeartifact.model.primitives.DomainName(impl.domain())
    override val domainOwner: Option[AccountId] = scala
      .Option(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val repository: RepositoryName =
      zio.aws.codeartifact.model.primitives.RepositoryName(impl.repository())
    override val externalConnection: ExternalConnectionName =
      zio.aws.codeartifact.model.primitives
        .ExternalConnectionName(impl.externalConnection())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
  ): zio.aws.codeartifact.model.AssociateExternalConnectionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codeartifact_3-5.17.295.10-sources.jar: zio/aws/codeartifact/model/AssociateExternalConnectionRequest.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codeartifact.model.primitives.{
  ExternalConnectionName,
  RepositoryName,
  AccountId,
  DomainName
}
import scala.jdk.CollectionConverters.*
final case class AssociateExternalConnectionRequest(
    domain: DomainName,
    domainOwner: Optional[AccountId] = Optional.Absent,
    repository: RepositoryName,
    externalConnection: ExternalConnectionName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest = {
    import AssociateExternalConnectionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
      .builder()
      .domain(DomainName.unwrap(domain): java.lang.String)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .repository(RepositoryName.unwrap(repository): java.lang.String)
      .externalConnection(
        ExternalConnectionName.unwrap(externalConnection): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.AssociateExternalConnectionRequest.ReadOnly =
    zio.aws.codeartifact.model.AssociateExternalConnectionRequest
      .wrap(buildAwsValue())
}
object AssociateExternalConnectionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.AssociateExternalConnectionRequest =
      zio.aws.codeartifact.model.AssociateExternalConnectionRequest(
        domain,
        domainOwner.map(value => value),
        repository,
        externalConnection
      )
    def domain: DomainName
    def domainOwner: Optional[AccountId]
    def repository: RepositoryName
    def externalConnection: ExternalConnectionName
    def getDomain: ZIO[Any, Nothing, DomainName] = ZIO.succeed(domain)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getRepository: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repository)
    def getExternalConnection: ZIO[Any, Nothing, ExternalConnectionName] =
      ZIO.succeed(externalConnection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
  ) extends zio.aws.codeartifact.model.AssociateExternalConnectionRequest.ReadOnly {
    override val domain: DomainName =
      zio.aws.codeartifact.model.primitives.DomainName(impl.domain())
    override val domainOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val repository: RepositoryName =
      zio.aws.codeartifact.model.primitives.RepositoryName(impl.repository())
    override val externalConnection: ExternalConnectionName =
      zio.aws.codeartifact.model.primitives
        .ExternalConnectionName(impl.externalConnection())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionRequest
  ): zio.aws.codeartifact.model.AssociateExternalConnectionRequest.ReadOnly =
    new Wrapper(impl)
}
